@@ -247,7 +247,7 @@ sub _functor {
 
 =head1 AUTHOR
 
-Gustavo Chaves, C<< <gustavo+perl at gnustavo.com> >>
+Gustavo Chaves, C<< <gnustavo@cpan.org> >>
 
 =head1 BUGS
 
